/// <reference types="node" />
import { signalservice as Proto } from '../../protos/compiled';
import { UUIDKind } from '../types';
import { Group } from './group';
import { PrimaryDevice } from './primary-device';
export declare type StorageStateRecord = Readonly<{
    type: Proto.ManifestRecord.Identifier.Type;
    key: Buffer;
    record: Proto.IStorageRecord;
}>;
export declare type StorageStateNewRecord = Readonly<{
    type: Proto.ManifestRecord.Identifier.Type;
    key?: Buffer;
    record: Proto.IStorageRecord;
}>;
export declare type DiffResult = Readonly<{
    added: ReadonlyArray<Proto.IStorageRecord>;
    removed: ReadonlyArray<Proto.IStorageRecord>;
}>;
export declare class StorageState {
    readonly version: number;
    private readonly items;
    constructor(version: number, items: ReadonlyArray<StorageStateRecord>);
    static getEmpty(): StorageState;
    getAccountRecord(): Proto.IAccountRecord | undefined;
    updateAccount(diff: Proto.IAccountRecord): StorageState;
    getGroup(group: Group): Proto.IGroupV2Record | undefined;
    addGroup(group: Group, diff?: Proto.IGroupV2Record): StorageState;
    updateGroup(group: Group, diff: Proto.IGroupV2Record): StorageState;
    pinGroup(group: Group): StorageState;
    unpinGroup(group: Group): StorageState;
    isGroupPinned(group: Group): boolean;
    addContact({ device }: PrimaryDevice, diff?: Proto.IContactRecord, uuidKind?: UUIDKind): StorageState;
    updateContact({ device }: PrimaryDevice, diff: Proto.IContactRecord, uuidKind?: UUIDKind): StorageState;
    getContact({ device }: PrimaryDevice, uuidKind?: UUIDKind): Proto.IContactRecord | undefined;
    removeContact({ device }: PrimaryDevice, uuidKind?: UUIDKind): StorageState;
    mergeContact(primary: PrimaryDevice, diff: Proto.IContactRecord): StorageState;
    pin(primary: PrimaryDevice, uuidKind?: UUIDKind): StorageState;
    unpin(primary: PrimaryDevice, uuidKind?: UUIDKind): StorageState;
    isPinned({ device }: PrimaryDevice): boolean;
    addRecord(newRecord: StorageStateNewRecord): StorageState;
    findRecord(find: (record: StorageStateRecord) => boolean): StorageStateRecord | undefined;
    hasRecord(find: (record: StorageStateRecord) => boolean): boolean;
    updateRecord(find: (item: StorageStateRecord) => boolean, map: (record: Proto.IStorageRecord) => Proto.IStorageRecord): StorageState;
    removeRecord(find: (item: StorageStateRecord) => boolean): StorageState;
    getAllGroupRecords(): ReadonlyArray<StorageStateRecord>;
    createWriteOperation(storageKey: Buffer, previous?: StorageState): Proto.IWriteOperation;
    inspect(): string;
    diff(oldState: StorageState): DiffResult;
    private addItem;
    private updateItem;
    private replaceItem;
    private removeItem;
    private changePin;
    private changeGroupPin;
    private static createStorageID;
}
