/// <reference types="node" />
import { Buffer } from 'buffer';
import { PrivateKey, PublicKey, SenderCertificate } from '@signalapp/libsignal-client';
import { signalservice as Proto } from '../protos/compiled';
import { Attachment } from './data/attachment';
import { DeviceId, UUID } from './types';
export declare type EncryptedProvisionMessage = {
    body: Buffer;
    ephemeralKey: Buffer;
};
export declare type ServerCertificate = {
    privateKey: PrivateKey;
    certificate: Proto.IServerCertificate;
};
export declare type Sender = {
    readonly uuid: UUID;
    readonly number?: string;
    readonly deviceId: DeviceId;
    readonly identityKey: PublicKey;
    readonly expires?: number;
};
export declare function encryptProvisionMessage(data: Buffer, remotePubKey: PublicKey): EncryptedProvisionMessage;
export declare function encryptAttachment(cleartext: Buffer): Attachment;
export declare function generateServerCertificate(rootKey: PrivateKey): ServerCertificate;
export declare function generateSenderCertificate(serverCert: ServerCertificate, sender: Sender): SenderCertificate;
export declare function deriveAccessKey(profileKey: Buffer): Buffer;
export declare function decryptStorageManifest(storageKey: Buffer, manifest: Proto.IStorageManifest): Proto.IManifestRecord;
export declare function encryptStorageManifest(storageKey: Buffer, manifestRecord: Proto.IManifestRecord): Proto.IStorageManifest;
export declare function decryptStorageItem(storageKey: Buffer, item: Proto.IStorageItem): Proto.IStorageRecord;
export declare function encryptStorageItem(storageKey: Buffer, key: Buffer, record: Proto.IStorageRecord): Proto.IStorageItem;
export declare function encryptProfileName(profileKey: Buffer, name: string): Buffer;
export declare function generateAccessKeyVerifier(accessKey: Buffer): Buffer;
