"use strict";
// Copyright 2022 Signal Messenger, LLC
// SPDX-License-Identifier: AGPL-3.0-only
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeContacts = void 0;
const compiled_1 = require("../../protos/compiled");
function serializeContacts(contacts) {
    const chunks = contacts.map((contact) => {
        const { uuid, number, profileName: name, profileKey } = contact;
        return Buffer.from(compiled_1.signalservice.ContactDetails.encode({
            uuid,
            number,
            name,
            profileKey,
        }).finish());
    }).map((chunk) => {
        const size = [];
        let remaining = chunk.length;
        do {
            let element = remaining & 0x7f;
            remaining >>>= 7;
            if (remaining !== 0) {
                element |= 0x80;
            }
            size.push(element);
        } while (remaining !== 0);
        return [
            Buffer.from(size),
            chunk,
        ];
    });
    return Buffer.concat(chunks.flat());
}
exports.serializeContacts = serializeContacts;
