/// <reference types="node" />
import { ProtocolAddress } from '@signalapp/libsignal-client';
import type { RegistrationId } from './types';
export declare type PromiseQueueConfig = Readonly<{
    timeout?: number;
}>;
export declare type MultiRecipientMessageRecipient = Readonly<{
    uuid: string;
    deviceId: number;
    registrationId: number;
    material: Buffer;
}>;
export declare type MultiRecipientMessage = Readonly<{
    recipients: ReadonlyArray<MultiRecipientMessageRecipient>;
    commonMaterial: Buffer;
}>;
export declare function generateRandomE164(): string;
export declare type ParseAuthHeaderResult = {
    username: string;
    password: string;
    error?: undefined;
} | {
    username?: undefined;
    password?: undefined;
    error: string;
};
export declare function parseAuthHeader(header?: string): ParseAuthHeaderResult;
export declare class PromiseQueue<T> {
    private readonly defaultTimeout;
    private readonly entries;
    private readonly resolvers;
    constructor(config?: PromiseQueueConfig);
    pushAndWait(value: T, timeout?: number | undefined): Promise<void>;
    push(value: T): void;
    shift(timeout?: number | undefined): Promise<T>;
}
export declare function addressToString(address: ProtocolAddress): string;
export declare function parseMultiRecipientMessage(message: Buffer): MultiRecipientMessage;
export declare function combineMultiRecipientMessage({ material, commonMaterial }: {
    material: Buffer;
    commonMaterial: Buffer;
}): Buffer;
export declare function getTodayInSeconds(): number;
export declare function generateRegistrationId(): RegistrationId;
